@@ -5,10 +5,10 @@
 #
 # File        : jiten/jmdict.py
 # Maintainer  : Felix C. Stegerman <flx@obfusk.net>
-# Date        : 2020-08-08
+# Date        : 2020-08-19
 #
 # Copyright   : Copyright (C) 2020  Felix C. Stegerman
-# Version     : v0.2.0
+# Version     : v0.3.0
 # License     : AGPLv3+
 #
 # --                                                            ; }}}1
@@ -28,6 +28,11 @@ JMDict.
 >>> print(jmdict[-1].sense[0].gloss[0])
 Japanese-Multilingual Dictionary Project - Creation Date: 2020-07-31
 
+>>> len([ x for x in jmdict if x.isprio() ])
+22437
+>>> len([ x for x in jmdict if x.isprio() and list(x.pitch()) ])
+14714
+
 >>> baka = [ x for x in jmdict if any( r.elem == "ばか" for r in x.reading ) ][0]
 >>> baka.seq
 1601260
@@ -454,6 +459,7 @@ def load_entry(c, seq):                                         # {{{1
   return Entry(seq, *( tuple(x) for x in [k, r, s] ))
                                                                 # }}}1
 
+# TODO
 def search(q, langs = [LANGS[0]], max_results = None,           # {{{1
            noun = False, verb = False, prio = False,
            file = SQLITE_FILE):
@@ -478,7 +484,7 @@ def search(q, langs = [LANGS[0]], max_results = None,           # {{{1
           ORDER BY prio DESC, rank ASC, seq ASC
           {}
         """.format(fltr, limit), (ord(q),))                   # safe!
-      elif all( M.iscjk(c) for c in q ):
+      elif M.iscjk(q):
         query = ("""
           SELECT rank, seq FROM (
               SELECT entry FROM kanji WHERE elem LIKE :q
@@ -490,6 +496,27 @@ def search(q, langs = [LANGS[0]], max_results = None,           # {{{1
           ORDER BY prio DESC, rank ASC, seq ASC
           {}
         """.format(fltr, limit), dict(q = "%"+q+"%"))         # safe!
+      elif M.q2like(q):
+        load_pcre_extension(c.connection)
+        prms  = dict(q = M.q2like(q), re = M.q2rx(q))
+        query = ("""
+          SELECT rank, seq FROM (
+              SELECT entry FROM kanji WHERE
+                elem LIKE :q AND elem REGEXP :re
+            UNION
+              SELECT entry FROM reading WHERE
+                elem LIKE :q AND elem REGEXP :re
+        """ + ("" if M.iscjk(M.without_e1w(q)) else """
+            UNION
+              SELECT entry FROM sense WHERE
+                lang IN ({}) AND gloss LIKE :q AND gloss REGEXP :re
+        """.format(lang)) + """
+          )
+          INNER JOIN entry ON seq = entry
+          {}
+          ORDER BY prio DESC, rank ASC, seq ASC
+          {}
+        """.format(fltr, limit), prms)                        # safe!
       else:
         load_pcre_extension(c.connection)
         query = ("""
